If you use acstools, please cite as:

[![ascl:2011.024](https://img.shields.io/badge/ascl-2011.024-blue.svg?colorB=262255)](https://ascl.net/2011.024)

#### Other forms of citation

[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.3728240.svg)](https://doi.org/10.5281/zenodo.3728240)
